========
Pylaroid
========

This app can generate fake self-developing film (like polaroid) from jpgs and
send it to printer.

.. start-badges

.. list-table::
    :stub-columns: 1

    * - tests
      - | |travis| |requires|
    * - package
      - | |version| |wheel| |supported-versions| |supported-implementations|
        | |commits-since|

.. |travis| image:: https://travis-ci.org/rage2000/pylaroid.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/rage2000/pylaroid

.. |requires| image:: https://requires.io/github/rage2000/pylaroid/requirements.svg?branch=master
    :alt: Requirements Status
    :target: https://requires.io/github/rage2000/pylaroid/requirements/?branch=master

.. |version| image:: https://img.shields.io/pypi/v/pylaroid.svg
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/pylaroid

.. |commits-since| image:: https://img.shields.io/github/commits-since/rage2000/pylaroid/0.0.1.svg
    :alt: Commits since latest release
    :target: https://github.com/rage2000/pylaroid/compare/0.0.1...master

.. |wheel| image:: https://img.shields.io/pypi/wheel/pylaroid.svg
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/pylaroid

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/pylaroid.svg
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/pylaroid

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/pylaroid.svg
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/pylaroid

.. end-badges
